@@ -17,6 +17,12 @@ class SyncariException(Exception):
     def __init__(self, error_response: ErrorResponse) -> None:
         self.error_response = error_response
 
+class NotSupportedException(Exception):
+    error_response = None
+    def __init__(self, error_response: ErrorResponse) -> None:
+        err_msg = "Operation is not supported" if error_response is None else error_response.message
+        self.error_response = ErrorResponse(message=err_msg, status_code=405)
+
 # pylint: disable=too-many-instance-attributes
 class SyncariRestClient:
 
@@ -25,19 +31,21 @@ class SyncariRestClient:
     """
         Default Syncari Rest Client
     """
-    def __init__(self, base_url, auth_config):
+    def __init__(self, base_url, auth_config, numRetries=5, backoff_factor=2):
         self.auth_config = auth_config
         self.rest_url = base_url
         self._session = requests.Session()
 
         retry_strategy = Retry(
-            total=3,
+            total=numRetries,
             status_forcelist=[429, 500, 502, 503, 504],
-            method_whitelist=["HEAD", "GET", "OPTIONS"]
+            backoff_factor=backoff_factor,
+            allowed_methods=["HEAD", "GET", "POST", "OPTIONS"],
+            raise_on_status=False
         )
-        adapter = HTTPAdapter(max_retries=retry_strategy)
+        #adapter = HTTPAdapter(max_retries=retry_strategy)
 
-        adapter = requests.adapters.HTTPAdapter(max_retries=3)
+        adapter = requests.adapters.HTTPAdapter(max_retries=retry_strategy)
         self._session.mount('https://', adapter)
 
     def get(self, path, **kwargs):
@@ -85,10 +93,6 @@ class SyncariRestClient:
                          kwargs, e)
             raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=str(e), status_code=500))
 
-        if resp.status_code == 500:
-            logger.error("Request to %s failed with status code %s, payload %s response %s",url, resp.status_code,kwargs, resp.text)
-            raise RetryableException(resp)
-
         if resp.status_code not in self.success_responses:
             logger.error("Request to %s failed with status code %s, payload %s response %s",url, resp.status_code,kwargs, resp.text)
             error_resp = ErrorResponse(message=err_msg, detail=self.__get_error_response_details(resp), status_code=resp.status_code)
