@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 import json
 from syncari.models import *
-from syncari.rest.client import SyncariException
+from syncari.rest.client import SyncariException, NotSupportedException
 from ..logger import SyncariLogger
 
 # pylint: disable=missing-function-docstring
@@ -14,6 +14,7 @@ class Synapse(ABC):
     request = None
     request_type = None
     init_error = None
+    _logger = None
 
     def __init__(self, raw_request: Request) -> None:
         try:
@@ -21,6 +22,7 @@ class Synapse(ABC):
             self.request_type = self.raw_request.type
             self.connection = self.raw_request.connection
             self.request = self.__set_request()
+            self._logger = None
         except Exception as e:
             err_msg = 'Failed to execute request {}'.format(raw_request.body)
             self.logger.error(err_msg)
@@ -159,6 +161,10 @@ class Synapse(ABC):
                 self.logger.error(self.request)
                 raise Exception('Invalid synapse request {}'.format(self.request_type))
 
+        except NotSupportedException as e:
+            err_msg = 'Operation Not Supported {}'.format(self.request_type)
+            response = e.error_response
+
         except SyncariException as e:
             err_msg = 'Failed to execute request {}'.format(self.request_type)
             response = e.error_response
@@ -186,7 +192,10 @@ class Synapse(ABC):
         err_msg = 'Invalid response type for request {}'.format(self.request_type)
         detail = 'The response: {}'.format(str(response))
         raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=detail, status_code=400))
-        
+
+    def raise_not_supported_exception(self):
+        raise NotSupportedException(error_response=ErrorResponse(message='Operation {} is not supported'.format(self.request_type), status_code=405))
+
     @property
     def name(self) -> str:
         """
@@ -205,6 +214,21 @@ class Synapse(ABC):
             return SyncariLogger.get_logger(f"{self.raw_request.syncariId}")
         return SyncariLogger.get_logger("custom_synapse")
 
+    @property
+    def logger(self):
+        # Check if the logger has already been created and cached
+        if self._logger is not None:
+            return self._logger
+
+        # Determine the logger name based on the presence of syncariId
+        if self.raw_request.syncariId is not None:
+            logger_name = f"{self.raw_request.syncariId}"
+            self._logger = SyncariLogger.get_logger(logger_name)
+        else:
+            self._logger = SyncariLogger.get_logger("custom_synapse")
+        
+        return self._logger
+
     @abstractmethod
     def synapse_info(self) -> SynapseInfo:
         pass
@@ -223,7 +247,7 @@ class Synapse(ABC):
 
     @abstractmethod
     def get_by_id(self, sync_request: SyncRequest) -> List[Record]:
-        pass
+        raise self.raise_not_supported_exception()
 
     @abstractmethod
     def create(self, sync_request: SyncRequest) -> List[Result]:
