@@ -3,6 +3,7 @@ import pytest
 from pytest import fail
 from syncari.rest.client import SyncariException, SyncariRestClient
 from syncari.logger import SyncariLogger
+from requests.adapters import HTTPAdapter
 
 logger = SyncariLogger.get_logger('test_router')
 
@@ -42,3 +43,26 @@ def test_get_exception():
     except Exception as e:
         fail('Invalid exception thrown from SyncariRestClient')
 
+
+def test_retry_strategy():
+    # missing / in the host.
+    rest_client = SyncariRestClient('https://httpstat.us', None, 2, 1)
+    adapter = rest_client._session.get_adapter("https://httpstat.us")
+    adapter.__class__ = HTTPAdapter
+    retryStrategy = adapter.max_retries
+    assert retryStrategy.total == 2
+    assert retryStrategy.backoff_factor == 1
+
+    try:
+        resp = rest_client.get('/500')
+    except SyncariException as e:
+        assert e.error_response.status_code == 500
+    except Exception as e:
+        fail('Invalid exception thrown from SyncariRestClient')
+
+    try:
+        resp = rest_client.get('/503')
+    except SyncariException as e:
+        assert e.error_response.status_code == 503
+    except Exception as e:
+        fail('Invalid exception thrown from SyncariRestClient')
